<?php
/*
Plugin Name: Hobbybrauer Alkoholgehalt Rechner
Plugin URI: https://www.brauerbund.org
Description: Ein Plugin, das den Alkoholgehalt beim Bierbrauen berechnet.
Version: 2.0
Author: Marcus Eickert
Author URI: https://www.brauerbund.org
License: Proprietary
*/

// Include the license checking class
include_once('license_checker.php');  

// Create a new instance of the license checker class
$alklicenseChecker = new alkLicenseChecker();

// Fge JavaScript und CSS hinzu
add_action('wp_enqueue_scripts', 'alkohol_rechner_enqueue_scripts');

function alkohol_rechner_enqueue_scripts() {
    wp_enqueue_style('alkohol-rechner-style', plugins_url('style.css', __FILE__));
    wp_enqueue_script('alkohol-rechner-script', plugins_url('script.js', __FILE__), array('jquery'), '1.0', true);
}

// Erstelle einen Shortcode fr den Bier-Rechner
add_shortcode('alkohol_rechner', 'alkohol_rechner_shortcode');

function alkohol_rechner_shortcode() {
global $alklicenseChecker;  // Access the global license checker instance
    ob_start();

   // Perform license check and handle submission of license form
    if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['license_code'])) {
        $valid_alklicense = $alklicenseChecker->check_license($_POST['license_code']);
    } else {
        $valid_alklicense = $alklicenseChecker->check_license();
    }

    if (!$valid_alklicense) {

        ?>
        Bitte geben Sie eine Lizenznummer ein:
        <form action="" method="POST">
            <input type="text" name="license_code" required>
            <input type="submit" value="&Uuml;berpr&uuml;fen">
        </form>
        <?php
    } else {

        ?>
        <div id="alkohol-rechner">
            <form id="alkohol-rechner-form" method="post">
                <label for="start_sg">Anfangsdichte (SG):</label>
                <input type="text" name="start_sg" id="start_sg" required>

                <label for="end_sg">Enddichte (SG):</label>
                <input type="text" name="end_sg" id="end_sg" required>

                <input type="submit" value="Berechnen">
            </form>

            <div id="alkohol-rechner-ergebnis"></div>
        </div>
        <?php
    }

    return ob_get_clean();
}

// Fge die JavaScript-Funktion hinzu, um den Alkoholgehalt zu berechnen
add_action('wp_footer', 'alkohol_rechner_js');

function alkohol_rechner_js() {
    ?>
    <script>
        jQuery(document).ready(function($) {
            $('#alkohol-rechner-form').on('submit', function(e) {
                e.preventDefault();

                var startSG = parseFloat($('#start_sg').val().replace(',', '.'));
                var endSG = parseFloat($('#end_sg').val().replace(',', '.'));

                if (isNaN(startSG) || isNaN(endSG) || startSG <= 0 || endSG <= 0 || startSG < endSG) {
                    $('#alkohol-rechner-ergebnis').html('<p class="error">Ung&uuml;ltige Eingabe. Bitte &uuml;berpr&uuml;fe deine Angaben.</p>');
                } else {
                    var abv = ((startSG - endSG) * 131.25).toFixed(2);
                    $('#alkohol-rechner-ergebnis').html('<p>Der Alkoholgehalt betr&auml;gt ' + abv + '%.</p>');
                }
            });
        });
    </script>
    <?php
}
